cordova.define("gamedock-sdk-cordova.gamedockSDK", function(require, exports, module) {
(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define(['exports'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.gamedockSDK = global.gamedockSDK || {}));
})(this, (function (exports) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    var eventemitter3 = {exports: {}};

    (function (module) {

    var has = Object.prototype.hasOwnProperty
      , prefix = '~';

    /**
     * Constructor to create a storage for our `EE` objects.
     * An `Events` instance is a plain object whose properties are event names.
     *
     * @constructor
     * @private
     */
    function Events() {}

    //
    // We try to not inherit from `Object.prototype`. In some engines creating an
    // instance in this way is faster than calling `Object.create(null)` directly.
    // If `Object.create(null)` is not supported we prefix the event names with a
    // character to make sure that the built-in object properties are not
    // overridden or used as an attack vector.
    //
    if (Object.create) {
      Events.prototype = Object.create(null);

      //
      // This hack is needed because the `__proto__` property is still inherited in
      // some old browsers like Android 4, iPhone 5.1, Opera 11 and Safari 5.
      //
      if (!new Events().__proto__) prefix = false;
    }

    /**
     * Representation of a single event listener.
     *
     * @param {Function} fn The listener function.
     * @param {*} context The context to invoke the listener with.
     * @param {Boolean} [once=false] Specify if the listener is a one-time listener.
     * @constructor
     * @private
     */
    function EE(fn, context, once) {
      this.fn = fn;
      this.context = context;
      this.once = once || false;
    }

    /**
     * Add a listener for a given event.
     *
     * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} context The context to invoke the listener with.
     * @param {Boolean} once Specify if the listener is a one-time listener.
     * @returns {EventEmitter}
     * @private
     */
    function addListener(emitter, event, fn, context, once) {
      if (typeof fn !== 'function') {
        throw new TypeError('The listener must be a function');
      }

      var listener = new EE(fn, context || emitter, once)
        , evt = prefix ? prefix + event : event;

      if (!emitter._events[evt]) emitter._events[evt] = listener, emitter._eventsCount++;
      else if (!emitter._events[evt].fn) emitter._events[evt].push(listener);
      else emitter._events[evt] = [emitter._events[evt], listener];

      return emitter;
    }

    /**
     * Clear event by name.
     *
     * @param {EventEmitter} emitter Reference to the `EventEmitter` instance.
     * @param {(String|Symbol)} evt The Event name.
     * @private
     */
    function clearEvent(emitter, evt) {
      if (--emitter._eventsCount === 0) emitter._events = new Events();
      else delete emitter._events[evt];
    }

    /**
     * Minimal `EventEmitter` interface that is molded against the Node.js
     * `EventEmitter` interface.
     *
     * @constructor
     * @public
     */
    function EventEmitter() {
      this._events = new Events();
      this._eventsCount = 0;
    }

    /**
     * Return an array listing the events for which the emitter has registered
     * listeners.
     *
     * @returns {Array}
     * @public
     */
    EventEmitter.prototype.eventNames = function eventNames() {
      var names = []
        , events
        , name;

      if (this._eventsCount === 0) return names;

      for (name in (events = this._events)) {
        if (has.call(events, name)) names.push(prefix ? name.slice(1) : name);
      }

      if (Object.getOwnPropertySymbols) {
        return names.concat(Object.getOwnPropertySymbols(events));
      }

      return names;
    };

    /**
     * Return the listeners registered for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Array} The registered listeners.
     * @public
     */
    EventEmitter.prototype.listeners = function listeners(event) {
      var evt = prefix ? prefix + event : event
        , handlers = this._events[evt];

      if (!handlers) return [];
      if (handlers.fn) return [handlers.fn];

      for (var i = 0, l = handlers.length, ee = new Array(l); i < l; i++) {
        ee[i] = handlers[i].fn;
      }

      return ee;
    };

    /**
     * Return the number of listeners listening to a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Number} The number of listeners.
     * @public
     */
    EventEmitter.prototype.listenerCount = function listenerCount(event) {
      var evt = prefix ? prefix + event : event
        , listeners = this._events[evt];

      if (!listeners) return 0;
      if (listeners.fn) return 1;
      return listeners.length;
    };

    /**
     * Calls each of the listeners registered for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @returns {Boolean} `true` if the event had listeners, else `false`.
     * @public
     */
    EventEmitter.prototype.emit = function emit(event, a1, a2, a3, a4, a5) {
      var evt = prefix ? prefix + event : event;

      if (!this._events[evt]) return false;

      var listeners = this._events[evt]
        , len = arguments.length
        , args
        , i;

      if (listeners.fn) {
        if (listeners.once) this.removeListener(event, listeners.fn, undefined, true);

        switch (len) {
          case 1: return listeners.fn.call(listeners.context), true;
          case 2: return listeners.fn.call(listeners.context, a1), true;
          case 3: return listeners.fn.call(listeners.context, a1, a2), true;
          case 4: return listeners.fn.call(listeners.context, a1, a2, a3), true;
          case 5: return listeners.fn.call(listeners.context, a1, a2, a3, a4), true;
          case 6: return listeners.fn.call(listeners.context, a1, a2, a3, a4, a5), true;
        }

        for (i = 1, args = new Array(len -1); i < len; i++) {
          args[i - 1] = arguments[i];
        }

        listeners.fn.apply(listeners.context, args);
      } else {
        var length = listeners.length
          , j;

        for (i = 0; i < length; i++) {
          if (listeners[i].once) this.removeListener(event, listeners[i].fn, undefined, true);

          switch (len) {
            case 1: listeners[i].fn.call(listeners[i].context); break;
            case 2: listeners[i].fn.call(listeners[i].context, a1); break;
            case 3: listeners[i].fn.call(listeners[i].context, a1, a2); break;
            case 4: listeners[i].fn.call(listeners[i].context, a1, a2, a3); break;
            default:
              if (!args) for (j = 1, args = new Array(len -1); j < len; j++) {
                args[j - 1] = arguments[j];
              }

              listeners[i].fn.apply(listeners[i].context, args);
          }
        }
      }

      return true;
    };

    /**
     * Add a listener for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} [context=this] The context to invoke the listener with.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.on = function on(event, fn, context) {
      return addListener(this, event, fn, context, false);
    };

    /**
     * Add a one-time listener for a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn The listener function.
     * @param {*} [context=this] The context to invoke the listener with.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.once = function once(event, fn, context) {
      return addListener(this, event, fn, context, true);
    };

    /**
     * Remove the listeners of a given event.
     *
     * @param {(String|Symbol)} event The event name.
     * @param {Function} fn Only remove the listeners that match this function.
     * @param {*} context Only remove the listeners that have this context.
     * @param {Boolean} once Only remove one-time listeners.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.removeListener = function removeListener(event, fn, context, once) {
      var evt = prefix ? prefix + event : event;

      if (!this._events[evt]) return this;
      if (!fn) {
        clearEvent(this, evt);
        return this;
      }

      var listeners = this._events[evt];

      if (listeners.fn) {
        if (
          listeners.fn === fn &&
          (!once || listeners.once) &&
          (!context || listeners.context === context)
        ) {
          clearEvent(this, evt);
        }
      } else {
        for (var i = 0, events = [], length = listeners.length; i < length; i++) {
          if (
            listeners[i].fn !== fn ||
            (once && !listeners[i].once) ||
            (context && listeners[i].context !== context)
          ) {
            events.push(listeners[i]);
          }
        }

        //
        // Reset the array, or remove it completely if we have no more listeners.
        //
        if (events.length) this._events[evt] = events.length === 1 ? events[0] : events;
        else clearEvent(this, evt);
      }

      return this;
    };

    /**
     * Remove all listeners, or those of the specified event.
     *
     * @param {(String|Symbol)} [event] The event name.
     * @returns {EventEmitter} `this`.
     * @public
     */
    EventEmitter.prototype.removeAllListeners = function removeAllListeners(event) {
      var evt;

      if (event) {
        evt = prefix ? prefix + event : event;
        if (this._events[evt]) clearEvent(this, evt);
      } else {
        this._events = new Events();
        this._eventsCount = 0;
      }

      return this;
    };

    //
    // Alias methods names because people roll like that.
    //
    EventEmitter.prototype.off = EventEmitter.prototype.removeListener;
    EventEmitter.prototype.addListener = EventEmitter.prototype.on;

    //
    // Expose the prefix.
    //
    EventEmitter.prefixed = prefix;

    //
    // Allow `EventEmitter` to be imported as module namespace.
    //
    EventEmitter.EventEmitter = EventEmitter;

    //
    // Expose the module.
    //
    {
      module.exports = EventEmitter;
    }
    }(eventemitter3));

    var EventEmitter = eventemitter3.exports;

    exports.GamedockCallbacks = void 0;
    (function (GamedockCallbacks) {
        GamedockCallbacks[GamedockCallbacks["InitializationCompleted"] = 0] = "InitializationCompleted";
        GamedockCallbacks[GamedockCallbacks["UserIdChangeRequest"] = 1] = "UserIdChangeRequest";
        GamedockCallbacks[GamedockCallbacks["UserIdChangeCompleted"] = 2] = "UserIdChangeCompleted";
        GamedockCallbacks[GamedockCallbacks["AgeGateStatus"] = 3] = "AgeGateStatus";
        GamedockCallbacks[GamedockCallbacks["PrivacyPolicyStatus"] = 4] = "PrivacyPolicyStatus";
        GamedockCallbacks[GamedockCallbacks["ConfigDataUpdated"] = 5] = "ConfigDataUpdated";
        GamedockCallbacks[GamedockCallbacks["ConfigError"] = 6] = "ConfigError";
        GamedockCallbacks[GamedockCallbacks["SplashScreenOpenShop"] = 7] = "SplashScreenOpenShop";
        GamedockCallbacks[GamedockCallbacks["SplashScreenOpen"] = 8] = "SplashScreenOpen";
        GamedockCallbacks[GamedockCallbacks["SplashScreenClosed"] = 9] = "SplashScreenClosed";
        GamedockCallbacks[GamedockCallbacks["SplashScreenAvailable"] = 10] = "SplashScreenAvailable";
        GamedockCallbacks[GamedockCallbacks["SplashScreenNotAvailable"] = 11] = "SplashScreenNotAvailable";
        GamedockCallbacks[GamedockCallbacks["SplashScreenData"] = 12] = "SplashScreenData";
        GamedockCallbacks[GamedockCallbacks["SplashScreenError"] = 13] = "SplashScreenError";
        GamedockCallbacks[GamedockCallbacks["IAPValid"] = 14] = "IAPValid";
        GamedockCallbacks[GamedockCallbacks["IAPInvalid"] = 15] = "IAPInvalid";
        GamedockCallbacks[GamedockCallbacks["IAPServerError"] = 16] = "IAPServerError";
        GamedockCallbacks[GamedockCallbacks["IAPRequestPurchase"] = 17] = "IAPRequestPurchase";
        GamedockCallbacks[GamedockCallbacks["LocalizationAvailable"] = 18] = "LocalizationAvailable";
        GamedockCallbacks[GamedockCallbacks["LocalizationNotAvailable"] = 19] = "LocalizationNotAvailable";
        GamedockCallbacks[GamedockCallbacks["LocalizationError"] = 20] = "LocalizationError";
        GamedockCallbacks[GamedockCallbacks["ATTPermissionStatus"] = 21] = "ATTPermissionStatus";
        GamedockCallbacks[GamedockCallbacks["AdTrigger"] = 22] = "AdTrigger";
    })(exports.GamedockCallbacks || (exports.GamedockCallbacks = {}));
    exports.ATTPermissionStatusEnum = void 0;
    (function (ATTPermissionStatusEnum) {
        ATTPermissionStatusEnum[ATTPermissionStatusEnum["NotDetermined"] = 0] = "NotDetermined";
        ATTPermissionStatusEnum[ATTPermissionStatusEnum["Restricted"] = 1] = "Restricted";
        ATTPermissionStatusEnum[ATTPermissionStatusEnum["Denied"] = 2] = "Denied";
        ATTPermissionStatusEnum[ATTPermissionStatusEnum["Authorized"] = 3] = "Authorized";
    })(exports.ATTPermissionStatusEnum || (exports.ATTPermissionStatusEnum = {}));
    var GamedockSDK = /** @class */ (function (_super) {
        __extends(GamedockSDK, _super);
        function GamedockSDK() {
            return _super.call(this) || this;
        }
        GamedockSDK.prototype.initialise = function (withAgeGate, ageGateOptions, withPrivacyPolicy, environment, externalIds) {
            console.log('Initialising Gamedock SDK');
            cordova.exec(this.success.bind(this), this.error.bind(this), 'GamedockSDKCordova', 'initialise', [{ withAgeGate: withAgeGate, ageGateOptions: ageGateOptions, withPrivacyPolicy: withPrivacyPolicy, environment: environment, externalIds: externalIds }]);
        };
        GamedockSDK.prototype.success = function (data) {
            var callback = JSON.parse(data);
            var callbackName = callback.name.toString();
            console.log("Received callback: " + callbackName + " and parameters: " + callback.message);
            switch (callbackName) {
                case "InitializationCompleted": {
                    this.emit(callbackName, "");
                    break;
                }
                case "UserIdChangeRequest": {
                    this.emit(callbackName, callback.message);
                    break;
                }
                case "UserIdChangeCompleted": {
                    this.emit(callbackName, "");
                    break;
                }
                case "AgeGateStatus": {
                    var ageGateStatus = JSON.parse(callback.message);
                    this.emit(callbackName, ageGateStatus);
                    break;
                }
                case "PrivacyPolicyStatus": {
                    var privacyPolicyStatus = JSON.parse(callback.message);
                    this.emit(callbackName, privacyPolicyStatus);
                    break;
                }
                case "ConfigDataUpdated": {
                    this.emit(callbackName, "");
                    break;
                }
                case "ConfigError": {
                    this.emit(callbackName, "");
                    break;
                }
                case "SplashScreenOpenShop": {
                    this.emit(callbackName, "");
                    break;
                }
                case "SplashScreenOpen": {
                    this.emit(callbackName, "");
                    break;
                }
                case "SplashScreenClosed": {
                    this.emit(callbackName, "");
                    break;
                }
                case "SplashScreenAvailable": {
                    var splashScreenType = JSON.parse(callback.message);
                    this.emit(callbackName, splashScreenType);
                    break;
                }
                case "SplashScreenNotAvailable": {
                    this.emit(callbackName, "");
                    break;
                }
                case "ATTPermissionStatus": {
                    var attPermissionStatus = JSON.parse(callback.message);
                    this.emit(callbackName, attPermissionStatus);
                    break;
                }
                case "LocalizationAvailable": {
                    var localizationInfo = JSON.parse(callback.message);
                    this.emit(callbackName, localizationInfo);
                    break;
                }
                case "LocalizationNotAvailable": {
                    this.emit(callbackName, "");
                    break;
                }
                case "LocalizationError": {
                    this.emit(callbackName, "");
                    break;
                }
                case "AdTrigger": {
                    this.emit(callbackName, "");
                    break;
                }
            }
            console.log('Success!', data);
        };
        GamedockSDK.prototype.error = function (error) {
            console.log('Error!', error);
            return this.emit('ERROR', error);
        };
        GamedockSDK.prototype.promisfyCordovaCall = function (service, action, data) {
            return new Promise(function (resolve, reject) {
                cordova.exec(function (result) { return resolve(result); }, function (error) { return reject(error); }, service, action, data);
            });
        };
        GamedockSDK.prototype.trackEvent = function (eventName, parameters) {
            console.log('Tracking event: ', eventName);
            this.promisfyCordovaCall('GamedockSDKCordova', 'trackEvent', [{ eventName: eventName, parameters: parameters }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.getFeatureVersionId = function (featureName) {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getFeatureVersionId', [{ featureName: featureName }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.setGDPRSettings = function (withPersonalisedAds, withPersonalisedContent) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'setGDPRSettings', [{ withPersonalisedAds: withPersonalisedAds, withPersonalisedContent: withPersonalisedContent }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.getGDPRSettings = function () {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getGDPRSettings', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.showPrivacyPolicySettings = function () {
            this.promisfyCordovaCall('GamedockSDKCordova', 'showPrivacyPolicySettings', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.addExternalId = function (externalPartner, id) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'addExternalId', [{ externalPartner: externalPartner, id: id }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.removeExternalId = function (externalPartner) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'removeExternalId', [{ externalPartner: externalPartner }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.getConfig = function () {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getConfig', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.requestSplashScreen = function (type) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'requestSplashScreen', [{ type: type }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.showSplashScreen = function () {
            this.promisfyCordovaCall('GamedockSDKCordova', 'showSplashScreen', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.getGamedockUserId = function () {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getGamedockUserId', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.getGamedockDeviceId = function () {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getGamedockDeviceId', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.requestLocalization = function (locale, fallbackToDefaultLocale) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'requestLocalization', [{ locale: locale, fallbackToDefaultLocale: fallbackToDefaultLocale }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.getLocalization = function (key, defaultValue) {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getLocalization', [{ key: key, defaultValue: defaultValue }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.getLocalizationArgs = function (key, defaultValue) {
            var args = [];
            for (var _i = 2; _i < arguments.length; _i++) {
                args[_i - 2] = arguments[_i];
            }
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getLocalizationArgs', [{ key: key, defaultValue: defaultValue, args: args }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.getLocalizationMap = function (key, defaultValue, args) {
            return this.promisfyCordovaCall('GamedockSDKCordova', 'getLocalizationMap', [{ key: key, defaultValue: defaultValue, args: args }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
                return result;
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
                return error.message;
            });
        };
        GamedockSDK.prototype.showAppRatePopup = function (rejectText, laterText, message, feedbackUrl, triggerCount, laterCount) {
            this.promisfyCordovaCall('GamedockSDKCordova', 'showAppRatePopup', [{ rejectText: rejectText, laterText: laterText, message: message, feedbackUrl: feedbackUrl, triggerCount: triggerCount, laterCount: laterCount }])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.requestATTPermission = function () {
            this.promisfyCordovaCall('GamedockSDKCordova', 'requestATTPermission', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.prototype.showAppSettings = function () {
            this.promisfyCordovaCall('GamedockSDKCordova', 'showAppSettings', [{}])
                .then(function (result) {
                console.log('Success!', JSON.stringify(result));
            })
                .catch(function (error) {
                console.log('Error!', JSON.stringify(error));
            });
        };
        GamedockSDK.Tracking = /** @class */ (function () {
            function class_1() {
            }
            class_1.CustomEvent = function (eventName) {
                return new BaseEvent(eventName, {});
            };
            class_1.MilestoneAchieved = function (name) {
                return new BaseMilestoneAchieved(name);
            };
            class_1.LevelStart = function (level) {
                return new BaseLevelStart(level);
            };
            class_1.LevelComplete = function (level) {
                return new BaseLevelComplete(level);
            };
            class_1.LevelFailed = function (level) {
                return new BaseLevelFailed(level);
            };
            class_1.IAPPurchased = function (skuId, transactionId) {
                return new BaseIAPPurchased(skuId, transactionId);
            };
            class_1.IAPRestored = function (skuId, originalTransactionId, originalPurchaseDate) {
                return new BaseIAPRestored(skuId, originalTransactionId, originalPurchaseDate);
            };
            class_1.IAPFailed = function (skuId, errorDescription) {
                return new BaseIAPFailed(skuId, errorDescription);
            };
            return class_1;
        }());
        return GamedockSDK;
    }(EventEmitter));
    var BaseEvent = /** @class */ (function () {
        function BaseEvent(eventName, parameters) {
            this.eventName = "";
            this.parameters = {};
            this.eventName = eventName;
            this.parameters = parameters;
        }
        BaseEvent.prototype.addCustomParameters = function (parameters) {
            for (var _i = 0, _a = Object.entries(parameters); _i < _a.length; _i++) {
                var _b = _a[_i], key = _b[0], value = _b[1];
                this.parameters[key] = value;
            }
            return this;
        };
        BaseEvent.prototype.addCustomParameter = function (key, value) {
            this.parameters[key] = value;
            return this;
        };
        BaseEvent.prototype.track = function () {
            var _this = this;
            console.log('Tracking event: ', this.eventName, ' with parameters: ', JSON.stringify(this.parameters));
            new Promise(function (resolve, reject) {
                cordova.exec(function (result) {
                    console.log('Success!', JSON.stringify(result));
                }, function (error) {
                    console.log('Error!', JSON.stringify(error));
                }, 'GamedockSDKCordova', 'trackEvent', [{ eventName: _this.eventName, parameters: _this.parameters }]);
            });
        };
        return BaseEvent;
    }());
    var BaseMilestoneAchieved = /** @class */ (function (_super) {
        __extends(BaseMilestoneAchieved, _super);
        function BaseMilestoneAchieved(name) {
            return _super.call(this, 'milestoneAchieved', {
                name: name
            }) || this;
        }
        BaseMilestoneAchieved.prototype.addMilestoneDescription = function (description) {
            this.parameters['description'] = description;
        };
        BaseMilestoneAchieved.prototype.addScore = function (score) {
            this.parameters['score'] = score;
        };
        BaseMilestoneAchieved.prototype.addLocation = function (location) {
            this.parameters['location'] = location;
        };
        BaseMilestoneAchieved.prototype.addIteration = function (iteration) {
            this.parameters['iteration'] = iteration;
        };
        return BaseMilestoneAchieved;
    }(BaseEvent));
    var BaseLevelStart = /** @class */ (function (_super) {
        __extends(BaseLevelStart, _super);
        function BaseLevelStart(level) {
            return _super.call(this, 'levelStart', {
                level: level
            }) || this;
        }
        BaseLevelStart.prototype.addLevelId = function (levelId) {
            this.parameters['levelId'] = levelId;
        };
        BaseLevelStart.prototype.addDifficulty = function (difficulty) {
            this.parameters['difficulty'] = difficulty;
        };
        BaseLevelStart.prototype.addCustomCreated = function (customCreated) {
            this.parameters['customCreated'] = customCreated;
        };
        BaseLevelStart.prototype.addCreatorId = function (creatorId) {
            this.parameters['creatorId'] = creatorId;
        };
        BaseLevelStart.prototype.addActiveBooster = function (activeBooster) {
            this.parameters['activeBooster'] = activeBooster;
        };
        BaseLevelStart.prototype.addAchievement = function (achievement) {
            this.parameters['achievement'] = achievement;
        };
        BaseLevelStart.prototype.addIteration = function (iteration) {
            this.parameters['iteration'] = iteration;
        };
        return BaseLevelStart;
    }(BaseEvent));
    var BaseLevelComplete = /** @class */ (function (_super) {
        __extends(BaseLevelComplete, _super);
        function BaseLevelComplete(level) {
            return _super.call(this, 'levelComplete', {
                level: level
            }) || this;
        }
        BaseLevelComplete.prototype.addLevelId = function (levelId) {
            this.parameters['levelId'] = levelId;
        };
        BaseLevelComplete.prototype.addDifficulty = function (difficulty) {
            this.parameters['difficulty'] = difficulty;
        };
        BaseLevelComplete.prototype.addScore = function (score) {
            this.parameters['score'] = score;
        };
        BaseLevelComplete.prototype.addStars = function (stars) {
            this.parameters['stars'] = stars;
        };
        BaseLevelComplete.prototype.addSpeed = function (speed) {
            this.parameters['speed'] = speed;
        };
        BaseLevelComplete.prototype.addMoves = function (moves) {
            this.parameters['moves'] = moves;
        };
        BaseLevelComplete.prototype.addTurns = function (turns) {
            this.parameters['turns'] = turns;
        };
        BaseLevelComplete.prototype.addCustomCreated = function (customCreated) {
            this.parameters['customCreated'] = customCreated;
        };
        BaseLevelComplete.prototype.addCreatorId = function (creatorId) {
            this.parameters['creatorId'] = creatorId;
        };
        BaseLevelComplete.prototype.addObjectUsed = function (objectUsed) {
            this.parameters['objectUsed'] = objectUsed;
        };
        BaseLevelComplete.prototype.addAchievement = function (achievement) {
            this.parameters['achievement'] = achievement;
        };
        BaseLevelComplete.prototype.addAvgCombos = function (avgCombos) {
            this.parameters['avgCombos'] = avgCombos;
        };
        BaseLevelComplete.prototype.addMovesLeft = function (movesLeft) {
            this.parameters['movesLeft'] = movesLeft;
        };
        BaseLevelComplete.prototype.addRating = function (rating) {
            this.parameters['rating'] = rating;
        };
        BaseLevelComplete.prototype.addTimeLeft = function (timeLeft) {
            this.parameters['timeLeft'] = timeLeft;
        };
        BaseLevelComplete.prototype.addIteration = function (iteration) {
            this.parameters['iteration'] = iteration;
        };
        return BaseLevelComplete;
    }(BaseEvent));
    var BaseLevelFailed = /** @class */ (function (_super) {
        __extends(BaseLevelFailed, _super);
        function BaseLevelFailed(level) {
            return _super.call(this, 'levelFailed', {
                level: level
            }) || this;
        }
        BaseLevelFailed.prototype.addLevelId = function (levelId) {
            this.parameters['levelId'] = levelId;
        };
        BaseLevelFailed.prototype.addDifficulty = function (difficulty) {
            this.parameters['difficulty'] = difficulty;
        };
        BaseLevelFailed.prototype.addScore = function (score) {
            this.parameters['score'] = score;
        };
        BaseLevelFailed.prototype.addStars = function (stars) {
            this.parameters['stars'] = stars;
        };
        BaseLevelFailed.prototype.addSpeed = function (speed) {
            this.parameters['speed'] = speed;
        };
        BaseLevelFailed.prototype.addMoves = function (moves) {
            this.parameters['moves'] = moves;
        };
        BaseLevelFailed.prototype.addTurns = function (turns) {
            this.parameters['turns'] = turns;
        };
        BaseLevelFailed.prototype.addCustomCreated = function (customCreated) {
            this.parameters['customCreated'] = customCreated;
        };
        BaseLevelFailed.prototype.addCreatorId = function (creatorId) {
            this.parameters['creatorId'] = creatorId;
        };
        BaseLevelFailed.prototype.addObjectUsed = function (objectUsed) {
            this.parameters['objectUsed'] = objectUsed;
        };
        BaseLevelFailed.prototype.addAchievement = function (achievement) {
            this.parameters['achievement'] = achievement;
        };
        BaseLevelFailed.prototype.addAvgCombos = function (avgCombos) {
            this.parameters['avgCombos'] = avgCombos;
        };
        BaseLevelFailed.prototype.addMovesLeft = function (movesLeft) {
            this.parameters['movesLeft'] = movesLeft;
        };
        BaseLevelFailed.prototype.addRating = function (rating) {
            this.parameters['rating'] = rating;
        };
        BaseLevelFailed.prototype.addTimeLeft = function (timeLeft) {
            this.parameters['timeLeft'] = timeLeft;
        };
        BaseLevelFailed.prototype.addIteration = function (iteration) {
            this.parameters['iteration'] = iteration;
        };
        return BaseLevelFailed;
    }(BaseEvent));
    var BaseIAPPurchased = /** @class */ (function (_super) {
        __extends(BaseIAPPurchased, _super);
        function BaseIAPPurchased(skuId, transactionId) {
            return _super.call(this, 'iapPurchased', {
                skuId: skuId,
                transactionId: transactionId,
                purchaseDate: new Date().toLocaleString()
            }) || this;
        }
        BaseIAPPurchased.prototype.addToken = function (token) {
            this.parameters['token'] = token;
        };
        BaseIAPPurchased.prototype.addReason = function (reason) {
            this.parameters['reason'] = reason;
        };
        BaseIAPPurchased.prototype.addReasonDetails = function (reasonDetails) {
            this.parameters['reasonDetails'] = reasonDetails;
        };
        BaseIAPPurchased.prototype.addLocation = function (location) {
            this.parameters['location'] = location;
        };
        BaseIAPPurchased.prototype.addIsSubscription = function (isSubscription) {
            this.parameters['isSubscription'] = isSubscription;
        };
        return BaseIAPPurchased;
    }(BaseEvent));
    var BaseIAPRestored = /** @class */ (function (_super) {
        __extends(BaseIAPRestored, _super);
        function BaseIAPRestored(skuId, originalTransactionId, originalPurchaseDate) {
            return _super.call(this, 'iapRestored', {
                skuId: skuId,
                originalTransactionId: originalTransactionId,
                originalPurchaseDate: originalPurchaseDate
            }) || this;
        }
        BaseIAPRestored.prototype.addReason = function (reason) {
            this.parameters['reason'] = reason;
        };
        BaseIAPRestored.prototype.addLocation = function (location) {
            this.parameters['location'] = location;
        };
        return BaseIAPRestored;
    }(BaseEvent));
    var BaseIAPFailed = /** @class */ (function (_super) {
        __extends(BaseIAPFailed, _super);
        function BaseIAPFailed(skuId, errorDescription) {
            return _super.call(this, 'iapFailed', {
                skuId: skuId,
                errorDescription: errorDescription
            }) || this;
        }
        BaseIAPFailed.prototype.addReason = function (reason) {
            this.parameters['reason'] = reason;
        };
        BaseIAPFailed.prototype.addLocation = function (location) {
            this.parameters['location'] = location;
        };
        return BaseIAPFailed;
    }(BaseEvent));
    window.gamedockSDK = new GamedockSDK();
    window.gamedockSDK.tracking = GamedockSDK.Tracking;

    exports.BaseEvent = BaseEvent;
    exports.BaseIAPFailed = BaseIAPFailed;
    exports.BaseIAPPurchased = BaseIAPPurchased;
    exports.BaseIAPRestored = BaseIAPRestored;
    exports.BaseLevelComplete = BaseLevelComplete;
    exports.BaseLevelFailed = BaseLevelFailed;
    exports.BaseLevelStart = BaseLevelStart;
    exports.BaseMilestoneAchieved = BaseMilestoneAchieved;
    exports.GamedockSDK = GamedockSDK;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=gamedockSDK.js.map

});
